<#assign import_block>
import { Environment } from '@/environments/environment';
</#assign>

<#ibizinclude>
../@MACRO/LAYOUTPANEL_VIEW.template.ftl
</#ibizinclude>

<#ibizinclude>
../@MACRO/VIEW_HEADER-BASE.vue.ftl
</#ibizinclude>

<#ibizinclude>
../@MACRO/VIEW_CONTENT-BASE.vue.ftl
</#ibizinclude>

    /**
     * 应用名称
     *
     * @type {string}
     * @memberof AppLoginViewBase
     */
    public appTitle: string = Environment.AppTitle;

    /**
     * 登录数据对象
     *
     * @type {*}
     * @memberof AppLoginViewBase
     */
    public formData: any = {
        loginname: '',
        password: ''
    }

    /**
    * 登录提示
    *
    * @type {*}
    * @memberof AppLoginViewBase
    */
    public loginTip: any = "";

    /**
     * 值规则
     *
     * @type {*}
     * @memberof AppLoginViewBase
     */
    public rules = {
        loginname: [
            {required: true, message: this.$t('components.login.loginname.message'), trigger: 'change'},
        ],
        password: [
            {required: true, message: this.$t('components.login.password.message'), trigger: 'change'},
        ],
    };

    /**
     * 登陆处理
     *
     * @memberof AppLoginViewBase
     */
    public handleSubmit(): void {
        // 清除cookie
        let leftTime = new Date();
        leftTime.setTime(leftTime.getSeconds() - 1000);
        document.cookie = "ibzuaa-token=;expires=" + leftTime.toUTCString();
        const form: any = this.$refs.loginForm;
        let validatestate: boolean = true;
        form.validate((valid: boolean) => {
            validatestate = valid ? true : false;
        });
        if (!validatestate) {
            return;
        }
        const loginname: any = this.formData.loginname;
        const password: any = this.formData.password;
        const post: Promise<any> = this.$http.post('/v7/login', this.formData, true);
        post.then((response: any) => {
            if (response && response.status === 200) {
                const data = response.data;
                if (data && data.token) {
                    localStorage.setItem('token', data.token);
                    Util.setCookie('ibzuaa-token',data.token,0);
                }
                if(data && data.user){
                    localStorage.setItem('user', JSON.stringify(data.user));
                }
                // 设置cookie,保存账号密码7天
                Util.setCookie("loginname",loginname, 7);
                // 跳转首页
                const url: any = this.$route.query.redirect ? this.$route.query.redirect : '*';
                this.$router.push({path: url});
            }
        }).catch((error: any) => {
            // 登录提示
            const data = error.data;
            if (data && data.message) {
                this.loginTip = data.message;
                this.$Message.error({
                    content: (this.$t('components.login.loginfailed') as string)+' ' + data.message,
                    duration: 5,
                    closable: true
                });
            } else {
                this.$Message.error({
                    content: (this.$t('components.login.loginfailed') as string),
                    duration: 5,
                    closable: true
                });
            }
        });
    }

    /**
     * 重置页面
     * 
     * @memberof AppLoginViewBase
     */
    public goReset(): void {
        this.formData = {loginname: 'ibzadmin', password: '123456'};
    }

    /**
     * qq授权登录
     * @param AppLoginViewBase
     */
    public tencentHandleClick() {
        this.$Message.warning((this.$t('components.login.warning1') as string))
    }

    /**
     * 微信授权登录
     * @param AppLoginViewBase
     */
    public wechatHandleClick() {
        this.$Message.warning((this.$t('components.login.warning2') as string))
    }

<#ibizinclude>
../@MACRO/VIEW_BOTTOM-BASE.vue.ftl
</#ibizinclude>

<#ibizinclude>
../@MACRO/VIEW-BASE.style.ftl
</#ibizinclude>